function [outputImg] = motion(inputImg, start, stop, amp, frq, projectors, detectors, filter)
% Funkce motion provede vypocet pohyboveho artefaktu
% 
% outputImg = motion(inputImg, start, stop, amp, frq, projectors, detectors, filter)
% 
% Vstupni promenne:
%       inputImg   - model scena
%       start      - pocatecni bod krivky
%       stop       - koncovy bod krivky
%       amp        - hloubka nadechu
%       frq        - frekvence dychani
%       projector  - pocet projektoru
%       detectors  - pocet detektoru
%       filter     - filtr pro inverzni transformaci
% 
% Vystupni promenne:
%       outputImg  - vystupni obrazek s artefaktem

    steps = length(projectors);

    x = start:((stop-start)/steps):stop;
    fx = amp*sin(frq.*x);
    
    if start == stop
        fx = zeros(steps, 1);
    end
    
    h = waitbar(0,'Probh vpoet...');

    
    for i=1:1:steps
        ss = 1 + fx(i);
        [ysize1, xsize1, map1] = size(inputImg);
        
        scale = GetScale(min([ysize1, xsize1]), ss);
        cImgS = imresize(inputImg, scale);
        
        if scale > 1.0
           [ysize1, xsize1, map1] = size(inputImg);
           [ysize2, xsize2, map2] = size(cImgS);
           
           sDiffX = (xsize2 - xsize1)/2;
           sDiffY = (ysize2 - ysize1)/2;
           
           cImg = cImgS(sDiffX+1:sDiffX+xsize1, sDiffY+1:sDiffY+ysize1);
        elseif scale < 1.0
           [ysize1, xsize1, map1] = size(inputImg);
           [ysize2, xsize2, map2] = size(cImgS);
           
           sDiffX = (xsize1 - xsize2)/2;
           sDiffY = (ysize1 - ysize2)/2;
           
           cImg = zeros(ysize1, xsize1);
           
           cImg(sDiffX+1:sDiffX+xsize2, sDiffY+1:sDiffY+ysize2) = cImgS;
        else
            [ysize1, xsize1, map1] = size(inputImg);
            cImg = cImgS(1:ysize1, 1:xsize1);
        end
        
%         theta = 0:2:359;
        [R,xp] = radon(cImg, projectors(i), detectors);
        
        if i==1
           [yR, xR] = size(R);
           outputMtx = zeros(yR, xR);
        end
        
%         outputMtx(:, i) = R(:, i);
          outputMtx(:, i) = R(:, 1);
          
          waitbar(i / steps);

        
    end

    outputImg = iradon(outputMtx, projectors, filter);
    close(h);
end


function [scale] = GetScale(imgSize, ss)

max = 0;
if imgSize >= 10 && imgSize < 100
    max = 1;
    fac = 10;
elseif imgSize >= 100 && imgSize < 1000
    max = 2;
    fac = 100;
elseif imgSize >= 1000 && imgSize < 10000
    max = 3;
    fac = 1000;
elseif imgSize >= 10000 && imgSize < 100000
    max = 4;
    fac = 10000;
elseif imgSize >= 100000
    max = 5;
    fac = 1000000;
end

    scale = fix(ss*fac)/(fac);

end




