function [outputImg] = Ring(inputImg, data, sizeData, projectors, detectors, filter, automatic)
% Funkce Ring provede vypocet kruhoveho artefaktu
% 
% outputImg = Ring(inputImg, data, sizeData, projectors, detectors, filter, automatic)
% 
% Vstupni promenne:
%       inputImg   - model scena
%       data       - tabulka detektoru pro manualni voleni
%                  - SNR pro automaticke voleni
%       sizeData   - pocet menenych detektoru
%       projectors - pocet projekci
%       detectors  - pocet detektoru
%       filter     - filtr pro inverzni transformaci
%       automatic  - voli automaticky (-1) a manualni (0) mod
% 
% Vystupni promenne:
%       outputImg  - vystupni obrazek s artefaktem

        

    [yImg, xImg, mImg] = size(inputImg);
    if yImg > 0 && xImg > 0

        % radonova transformace
        h = waitbar(0,'Probh vpoet...');
        [R,xp] = GetRadon(inputImg, projectors, detectors);
        waitbar(1 / 3);

        % vektor vah
        [yR, xR] = size(R);
        weights = ones(yR,1);

        % manualni mod
        if automatic == -1
            for i=1:1:sizeData
                 weights(data(i, 1), 1) = data(i, 2)./100;
            end
        else
        % automaticky mod
            rnd = randi(detectors,[1 sizeData]);
            for i=1:1:sizeData
                weights(rnd(1, i), 1) = awgn(1, data);
            end

        end
        
        % vytvoreni artefaktu
        waitbar(2 / 3);
        r2 = zeros(yR, xR);
        for i=1:1:xR
            r2(:, i) = R(:, i).*weights;
        end

        % zpetna transformace
        outputImg = iradon(r2, projectors, filter);
        waitbar(3 / 3);
        close(h);
    else
        return;
    end   

end

