function [outputImg] = Streak(inputImg, projectors, detectors, filter)
% Funkce Streak provede vypocet streak artefaktu
% 
% outputImg = Streak(inputImg, projectors, detectors, filter)
% 
% Vstupni promenne:
%       inputImg   - model scena
%       projector  - pocet projektoru
%       detectors  - pocet detektoru
%       filter     - filtr pro inverzni transformaci
% 
% Vystupni promenne:
%       outputImg  - vystupni obrazek s artefaktem



I = inputImg;

in_dlg_title = 'Parametr';
prompt{1} = 'Volba rovn artefaktu: ';
parameters = inputdlg(prompt, in_dlg_title, [1 15], {'1.8'});

[ysize, xsize,map] = size(parameters);
if (ysize == 0) || (xsize == 0)
    outputImg = -1;
    return;
end


prah = str2double(parameters{1});

I0 = 1.0;
mju = 0.05;

[R,xp] = GetRadon(I, projectors, detectors);
[yR, xR] = size(R);

r2 = zeros(yR, xR);

h = waitbar(0,'Probh vpoet...');


for i=0:1:(length(projectors)-1)
    
    Itmp = imrotate(I, projectors(i+1), 'nearest', 'crop');
    [Rtmp,xptmp] = GetRadon(Itmp, 1, detectors);
    [RtmpYsize, RtmpXsize] = size(Rtmp);
    
    % sumace
    [ysize, xsize] = size(Itmp);
    Dtmp = zeros(1, xsize);
    for j=1:1:xsize
        for k=1:1:ysize
            if Itmp(k, j) > 0
                Dtmp(1, j) = Dtmp(1, j) + Itmp(k, j);
            end
        end
    end
    
    % minimum, maximum sumace
    dmin = 0;
    dmax = 0;
    for j=1:1:xsize
        if (Dtmp(1,j) > 0) && (dmin == 0)
            dmin = j;
        end
        if (Dtmp(1,j) == 0) && (dmin > 0) && (dmax == 0)
            dmax = j;
        end  
    end   
    
    % minimum, maximum, orotovanyho
    rmin = 0;
    rmax = 0;
    for j=1:1:RtmpYsize
        if (Rtmp(j,1) > 0) && (rmin == 0)
            rmin = j;
        end
        if (Rtmp(j,1) == 0) && (rmin > 0) && (rmax == 0)
            rmax = j;
        end  
    end
    
    % srovnani rozmeru
    roztazene = imresize(Dtmp(1, dmin:(dmax-1)), [1, (rmax-rmin)+1]);
    
    % vypocet utlumu
    utlum = zeros(1, RtmpYsize);
    for j=1:1:length(rmin:1:rmax)
        it = j;
        it2 = rmin + j -1;
        utlum(1, it2) = I0.*exp(-mju*roztazene(it));
        
    end
    
    % otoceni do kladna
    tmpmax = max(max(utlum));
    added = zeros(1, RtmpYsize);
    for j=1:1:RtmpYsize
        if (j >= rmin) && (j <= rmax)
            added(1, j) = tmpmax + abs(tmpmax-utlum(1,j));
        else
            added(1,j) = utlum(1,j);
        end
    end
    r2(:, i+1) = added';
    
    waitbar(i / length(projectors));

end

close(h);


%% omezeni a vypocet artefaktu
test = zeros(yR, xR);
maximum2 = max(max(r2));
rTmp = r2./maximum2;
for i=1:1:yR
    for j=1:1:xR
        if (r2(i,j) == 0) || (r2(i,j) <= prah)
            continue;
        end
        
        db = 70 - rTmp(i,j).*60;
        cSum = awgn(1, db, 0);
        test(i,j) = abs(1-cSum);
    end
end
rout2 = R + 40*test;

outputImg = GetIRadon(rout2, projectors, filter);



